@@ -8,10 +8,14 @@ class networksettings:
 	if os.name == "nt":
 		WIRELESS_OPTS = "C:\\python24\\pdaxrom\\misc\\wireless.opts"
 		NETWORK_OPTS = "C:\\python24\\pdaxrom\\misc\\network.opts"
+		i686_NETWORK_OPTS = "C:\\python24\\pdaxrom\\misc\\network"
+		i686_WIRELESS_OPTS = "C:\\python24\\pdaxrom\\misc\\wireless"
 		CFG_FILENAME = "network.cfg"
 	else:
 		WIRELESS_OPTS = "/etc/pcmcia/wireless.opts"
 		NETWORK_OPTS = "/etc/pcmcia/network.opts"
+		i686_NETWORK_OPTS = "/etc/sysconfig/network"
+		i686_WIRELESS_OPTS = "/etc/sysconfig/wireless"
 		CFG_FILENAME = os.environ['HOME'] + "/Choices/network.cfg"
 	
 	NOTINUPDATEMODE = True
@@ -808,14 +812,30 @@ case "$ADDRESS" in
 		
 		self.make_output_files()
 
-		if (self.OUTPUT_WIRELESS <> ""):
-			f=open(self.WIRELESS_OPTS, 'w')
-			f.write(self.wireless_header + self.OUTPUT_WIRELESS.strip() + self.wireless_footer)
+	        if os.path.isdir("/etc/pcmcia"):
+			if (self.OUTPUT_WIRELESS <> ""):
+				f=open(self.WIRELESS_OPTS, 'w')
+				f.write(self.wireless_header + self.OUTPUT_WIRELESS.strip() + self.wireless_footer)
+				f.close()
+	
+			if (self.OUTPUT_NETWORK <> ""):
+				f=open(self.NETWORK_OPTS, 'w')
+				f.write(self.network_header + self.OUTPUT_NETWORK.strip() + self.network_footer)
+				f.close()
+
+
+		if (self.default_append_wireless <> ""):
+			f=open(self.i686_WIRELESS_OPTS, 'w')
+			self.default_append_wireless = self.default_append_wireless.replace(";;","")
+			self.default_append_wireless = self.default_append_wireless.replace("*,*,*,*|default,*,*,*)","")
+			f.write(self.default_append_wireless)
 			f.close()
 
-		if (self.OUTPUT_NETWORK <> ""):
-			f=open(self.NETWORK_OPTS, 'w')
-			f.write(self.network_header + self.OUTPUT_NETWORK.strip() + self.network_footer)
+		if (self.default_append <> ""):
+			f=open(self.i686_NETWORK_OPTS, 'w')
+			self.default_append = self.default_append.replace(";;","")
+			self.default_append = self.default_append.replace("*,*,*,*|default,*,*,*)","")
+			f.write(self.default_append)
 			f.close()
 		return True
 
@@ -873,8 +893,8 @@ case "$ADDRESS" in
 	def make_output_files(self):
 		returnstr_wireless = ""
 		returnstr_network = ""
-		default_append_wireless = ""
-		default_append = ""
+		self.default_append_wireless = ""
+		self.default_append = ""
 		if os.path.isfile(self.CFG_FILENAME):
 			try:
 				xmldoc = minidom.parse(self.CFG_FILENAME)
@@ -928,7 +948,7 @@ case "$ADDRESS" in
 						returnstr_network = returnstr_network.strip()+"\n\n"
 
 						if (Networkset.getAttribute("SETTINGNAME") == "default"):
-							default_append = returnstr_network
+							self.default_append = returnstr_network
 						else:
 							self.OUTPUT_NETWORK += returnstr_network
 
@@ -976,15 +996,15 @@ case "$ADDRESS" in
 							returnstr_wireless = returnstr_wireless.strip() + "\n\n"
 							
 							if (Networkset.getAttribute("SETTINGNAME") == "default"):
-								default_append_wireless = returnstr_wireless
+								self.default_append_wireless = returnstr_wireless
 							else:
 								self.OUTPUT_WIRELESS += returnstr_wireless
+				print self.OUTPUT_WIRELESS
+				if (self.default_append != ""):
+					self.OUTPUT_NETWORK += self.default_append
 
-				if (default_append != ""):
-					self.OUTPUT_NETWORK += default_append
-
-				if (default_append_wireless != ""):
-					self.OUTPUT_WIRELESS += default_append_wireless
+				if (self.default_append_wireless != ""):
+					self.OUTPUT_WIRELESS += self.default_append_wireless
 
 				return True
 		else:
